@@ -10,12 +10,12 @@ pub(crate) trait PlatformInterface {
   ) -> Result<Command, OutputError>;
 
   /// Set the execute permission on the file pointed to by `path`
-  fn set_execute_permission(path: &Path) -> Result<(), io::Error>;
+  fn set_execute_permission(path: &Path) -> io::Result<()>;
 
   /// Extract the signal from a process exit status, if it was terminated by a
   /// signal
-  fn signal_from_exit_status(exit_status: process::ExitStatus) -> Option<i32>;
+  fn signal_from_exit_status(exit_status: ExitStatus) -> Option<i32>;
 
   /// Translate a path from a "native" path to a path the interpreter expects
-  fn convert_native_path(working_directory: &Path, path: &Path) -> Result<String, String>;
+  fn convert_native_path(working_directory: &Path, path: &Path) -> FunctionResult;
 }
